--
-- PostgreSQL database dump
--

SET client_encoding = 'SQL_ASCII';
SET check_function_bodies = false;

SET SESSION AUTHORIZATION 'pgsql';

--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: pgsql
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET SESSION AUTHORIZATION 'clariphony';

SET search_path = public, pg_catalog;

--
-- TOC entry 5 (OID 25336)
-- Name: operateur; Type: TABLE; Schema: public; Owner: clariphony
--

CREATE TABLE operateur (
    id_operateur serial NOT NULL,
    code text,
    nom text NOT NULL,
    tel text,
    email text,
    mail_notif boolean DEFAULT false
);


--
-- TOC entry 6 (OID 25344)
-- Name: societe; Type: TABLE; Schema: public; Owner: clariphony
--

CREATE TABLE societe (
    id_societe serial NOT NULL,
    code text,
    nom text NOT NULL,
    tel text,
    client boolean DEFAULT false
);


--
-- TOC entry 7 (OID 25353)
-- Name: appelant; Type: TABLE; Schema: public; Owner: clariphony
--

CREATE TABLE appelant (
    id_appelant serial NOT NULL,
    code text,
    nom text NOT NULL,
    tel text,
    email text,
    id_societe integer
);


--
-- TOC entry 8 (OID 25361)
-- Name: priorite; Type: TABLE; Schema: public; Owner: clariphony
--

CREATE TABLE priorite (
    id_priorite serial NOT NULL,
    libelle text,
    poids integer
);


--
-- TOC entry 9 (OID 25369)
-- Name: notification; Type: TABLE; Schema: public; Owner: clariphony
--

CREATE TABLE notification (
    id_notification serial NOT NULL,
    date_appel timestamp without time zone DEFAULT now() NOT NULL,
    id_appelant integer NOT NULL,
    id_operateur integer NOT NULL,
    id_priorite integer NOT NULL,
    a_rappeler boolean DEFAULT false,
    tel_rappel text,
    rappel_ok boolean DEFAULT false,
    contenu text NOT NULL,
    id_transfert integer,
    date_rappel timestamp without time zone
);


--
-- Data for TOC entry 23 (OID 25336)
-- Name: operateur; Type: TABLE DATA; Schema: public; Owner: clariphony
--

COPY operateur (id_operateur, code, nom, tel, email, mail_notif) FROM stdin;
1	dbg	debug			\N
\.


--
-- Data for TOC entry 26 (OID 25361)
-- Name: priorite; Type: TABLE DATA; Schema: public; Owner: clariphony
--

COPY priorite (id_priorite, libelle, poids) FROM stdin;
1	Haute	1
2	Basse	2
\.


--
-- TOC entry 16 (OID 25378)
-- Name: operateur_pkey; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY operateur
    ADD CONSTRAINT operateur_pkey PRIMARY KEY (id_operateur);


--
-- TOC entry 15 (OID 25380)
-- Name: operateur_code_key; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY operateur
    ADD CONSTRAINT operateur_code_key UNIQUE (code);


--
-- TOC entry 18 (OID 25382)
-- Name: societe_pkey; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY societe
    ADD CONSTRAINT societe_pkey PRIMARY KEY (id_societe);


--
-- TOC entry 17 (OID 25384)
-- Name: societe_code_key; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY societe
    ADD CONSTRAINT societe_code_key UNIQUE (code);


--
-- TOC entry 20 (OID 25386)
-- Name: appelant_pkey; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY appelant
    ADD CONSTRAINT appelant_pkey PRIMARY KEY (id_appelant);


--
-- TOC entry 19 (OID 25388)
-- Name: appelant_code_key; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY appelant
    ADD CONSTRAINT appelant_code_key UNIQUE (code);


--
-- TOC entry 21 (OID 25390)
-- Name: priorite_pkey; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY priorite
    ADD CONSTRAINT priorite_pkey PRIMARY KEY (id_priorite);


--
-- TOC entry 22 (OID 25392)
-- Name: notification_pkey; Type: CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT notification_pkey PRIMARY KEY (id_notification);


--
-- TOC entry 28 (OID 25394)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY appelant
    ADD CONSTRAINT "$1" FOREIGN KEY (id_societe) REFERENCES societe(id_societe);


--
-- TOC entry 29 (OID 25398)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT "$1" FOREIGN KEY (id_appelant) REFERENCES appelant(id_appelant);


--
-- TOC entry 30 (OID 25402)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT "$2" FOREIGN KEY (id_operateur) REFERENCES operateur(id_operateur);


--
-- TOC entry 31 (OID 25406)
-- Name: $3; Type: FK CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT "$3" FOREIGN KEY (id_priorite) REFERENCES priorite(id_priorite);


--
-- TOC entry 32 (OID 25410)
-- Name: $4; Type: FK CONSTRAINT; Schema: public; Owner: clariphony
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT "$4" FOREIGN KEY (id_transfert) REFERENCES operateur(id_operateur);


--
-- TOC entry 10 (OID 25334)
-- Name: operateur_id_operateur_seq; Type: SEQUENCE SET; Schema: public; Owner: clariphony
--

SELECT pg_catalog.setval('operateur_id_operateur_seq', 2, true);


--
-- TOC entry 11 (OID 25342)
-- Name: societe_id_societe_seq; Type: SEQUENCE SET; Schema: public; Owner: clariphony
--

SELECT pg_catalog.setval('societe_id_societe_seq', 1, true);


--
-- TOC entry 12 (OID 25351)
-- Name: appelant_id_appelant_seq; Type: SEQUENCE SET; Schema: public; Owner: clariphony
--

SELECT pg_catalog.setval('appelant_id_appelant_seq', 1, true);


--
-- TOC entry 13 (OID 25359)
-- Name: priorite_id_priorite_seq; Type: SEQUENCE SET; Schema: public; Owner: clariphony
--

SELECT pg_catalog.setval('priorite_id_priorite_seq', 3, true);


--
-- TOC entry 14 (OID 25367)
-- Name: notification_id_notification_seq; Type: SEQUENCE SET; Schema: public; Owner: clariphony
--

SELECT pg_catalog.setval('notification_id_notification_seq', 1, true);


SET SESSION AUTHORIZATION 'pgsql';

--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: pgsql
--

COMMENT ON SCHEMA public IS 'Standard public schema';


